#
# spec file for package python-matplotlib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
# Run on 64bit intel and arm only, on others there are >100 test failures
ExclusiveArch:  x86_64 aarch64
%else
%define psuffix %{nil}
%bcond_with test
%endif
%bcond_with ringdisabled
%{?sle15_python_module_pythons}
Name:           python-matplotlib%{psuffix}
Version:        3.8.4
Release:        1.2
Summary:        Plotting Library for Python
License:        SUSE-Matplotlib
URL:            https://matplotlib.org
Source:         https://files.pythonhosted.org/packages/source/m/matplotlib/matplotlib-%{version}.tar.gz
Source1:        matplotlib-mplsetup.cfg
# Bundled version of freetype and qhull for testing purposes only
Source98:       http://www.qhull.org/download/qhull-2020-src-8.0.2.tgz
Source99:       https://downloads.sourceforge.net/project/freetype/freetype2/2.6.1/freetype-2.6.1.tar.gz
Source100:      python-matplotlib.rpmlintrc
Recommends:     ghostscript
Recommends:     libxml2-tools
Recommends:     poppler-tools
Recommends:     python-certifi
Recommends:     (%{python_flavor}-matplotlib-tk if tk)
Provides:       python-matplotlib-gtk = %{version}
Obsoletes:      python-matplotlib-gtk < %{version}
# SECTION build
BuildRequires:  %{python_module devel >= 3.9}
BuildRequires:  %{python_module numpy-devel >= 1.25 with %python-numpy-devel < 2.3}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pybind11-devel >= 2.6}
BuildRequires:  %{python_module setuptools >= 64}
BuildRequires:  %{python_module setuptools_scm >= 7}
BuildRequires:  %{python_module wheel}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  qhull-devel >= 2003.1
# /SECTION
# SECTION tk dependencies via tcl
BuildRequires:  tcl
BuildRequires:  pkgconfig(freetype2) >= 2.3
BuildRequires:  pkgconfig(libpng) >= 1.2
BuildRequires:  pkgconfig(tcl)
# /SECTION
# SECTION runtime
Requires:       python-numpy >= 1.21
Requires:       python-Cycler >= 0.10
Requires:       python-FontTools >= 4.22.0
Requires:       python-Pillow >= 8
Requires:       python-contourpy >= 1.0.1
Requires:       python-kiwisolver >= 1.3.1
Requires:       python-packaging >= 20.0
Requires:       python-pyparsing > 2.3.1
Requires:       python-python-dateutil >= 2.7
%if 0%{?python_version_nodots} < 310
Requires:       python-importlib-resources >= 3.2.0
%endif
# /SECTION
# SECTION test
%if %{with test}
BuildRequires:  %{python_module matplotlib = %{version}}
BuildRequires:  %{python_module matplotlib-cairo = %{version}}
BuildRequires:  %{python_module matplotlib-gtk3 = %{version}}
BuildRequires:  %{python_module matplotlib-gtk4 = %{version}}
BuildRequires:  %{python_module matplotlib-qt5 = %{version}}
BuildRequires:  %{python_module matplotlib-testdata = %{version}}
BuildRequires:  %{python_module matplotlib-tk = %{version}}
BuildRequires:  %{python_module matplotlib-web = %{version}}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
%if 0%{?suse_version} > 1500
BuildRequires:  %{python_module matplotlib-nbagg = %{version} if %python-base >= 3.10}
%endif
%if 0%{?suse_version} > 1500
BuildRequires:  %{python_module matplotlib-wx = %{version}}
%endif
# SECTION latex test dependencies
BuildRequires:  %{python_module matplotlib-latex = %{version}}
BuildRequires:  Mesa-dri
BuildRequires:  ghostscript
BuildRequires:  inkscape
BuildRequires:  poppler-tools
# /SECTION latex
# SECTION cairo backend options
BuildRequires:  %{python_module cairo >= 1.14.0}
BuildRequires:  %{python_module cairocffi >= 0.8}
# /SECTION cairo
# SECTION nbagg backend tests
%if %{without ringdisabled} && 0%{?suse_version} > 1500
BuildRequires:  %{python_module nbconvert if %python-base >= 3.10}
BuildRequires:  %{python_module nbformat if %python-base >= 3.10}
%endif
# /SECTION nbagg
# SECTION qt backends: Only test PyQt5 in Minimal-X
BuildRequires:  %{python_module qt5}
%if %{without ringdisabled}
%if 0%{?suse_version} > 1500
BuildRequires:  %{python_module PyQt6}
BuildRequires:  python3-pyside2
BuildRequires:  python3-pyside6
%endif
%endif
# /SECTION qt
# /SECTION test
%endif
%python_subpackages

%description
matplotlib is a python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. matplotlib can be used in python
scripts, the python and ipython shell (ala matlab or mathematica), web
application servers, and six graphical user interface toolkits.

%package        cairo
Summary:        Cairo backend for %{name}
Requires:       %{name} = %{version}
Requires:       (python-cairo or python-cairocffi)

%description    cairo
This package includes the non-interactive Cairo-based backend
for the %{name} plotting package

%package        gtk3
Summary:        GTK3 backends for %{name}
Requires:       %{name} = %{version}
Requires:       %{name}-gtk-common = %{version}

%description    gtk3
This package includes the GTK3-based gtk3, gtk3agg, and
gtk3cairo backends for the %{name} plotting package

%package        gtk4
Summary:        GTK4 backends for %{name}
Requires:       %{name} = %{version}
Requires:       %{name}-gtk-common = %{version}

%description    gtk4
This package includes the GTK4-based gtk4, gtk4agg, and
gtk4cairo backends for the %{name} plotting package

%package        gtk-common
Summary:        Code common for GTK3 and GTK4 backends for %{name}
Requires:       %{name} = %{version}
Requires:       %{name}-cairo = %{version}
Requires:       gdk-pixbuf-loader-rsvg
Requires:       python-gobject-Gdk
Requires:       python-gobject-cairo

%description    gtk-common
This package provides code common for the GTK3 and GTK4 backends
for the %{name} plotting package

%package        nbagg
Summary:        Jupyter nbagg backend for %{name}
Requires:       %{name} = %{version}
Requires:       python-ipykernel

%description    nbagg
This package includes the Jupyter notebook backend
for the %{name} plotting package

%package        latex
Summary:        Allow rendering latex in %{name}
Requires:       %{name} = %{version}
# grep usepackage lib/matplotlib/texmanager.py lib/matplotlib/backends/backend_pgf.py
# https://github.com/search?q=usepackage+repo%3Amatplotlib%2Fmatplotlib+path%3Alib&type=Code
Requires:       texlive-dvipng
Requires:       texlive-dvips
Requires:       texlive-geometry
Requires:       texlive-graphics
Requires:       texlive-helvetic
Requires:       texlive-latex
Requires:       texlive-pgf
Requires:       texlive-sfmath
Requires:       texlive-tex
Requires:       texlive-txfonts
Requires:       texlive-xcolor
Requires:       texlive-xetex
Requires:       tex(avant.sty)
Requires:       tex(chancery.sty)
Requires:       tex(charter.sty)
Requires:       tex(courier.sty)
Requires:       tex(geometry.sty)
Requires:       tex(helvet.sty)
Requires:       tex(mathpazo.sty)
Requires:       tex(mathptmx.sty)
Requires:       tex(pncr.tfm)
Requires:       tex(psfrag.sty)
Requires:       tex(type1cm.sty)
Requires:       tex(type1ec.sty)
Requires:       tex(ucs.sty)
Requires:       tex(underscore.sty)
BuildArch:      noarch

%description    latex
This package allows %{name} to display latex in plots
and figures.

%package        qt
Summary:        Qt backend for %{name}
Requires:       %{name} = %{version}
Requires:       (python-qt5 or python-PyQt6 >= 6.1 or python-pyside2 or python-pyside6)
Provides:       %{name}-qt-shared = %{version}
Provides:       %{name}-qt5 = %{version}
Obsoletes:      %{name}-qt-shared < %{version}
# Renamed at upgrade from MPL 3.6.3 to 3.8.2
Obsoletes:      %{name}-qt5 < 3.8.2

%description    qt
This package includes the Qt-based backend
for the %{name} plotting package
PyQt5, PyQt6, Pyside2 or Pyside 6 may be used

%package        testdata
Summary:        Test data for %{name}
Requires:       %{name} = %{version}

%description    testdata
This package includes the test baseline data
for the %{name} plotting package

%package        tk
Summary:        Tk backend for %{name}
Requires:       %{name} = %{version}
Requires:       python-Pillow-tk
Requires:       python-tk
Requires:       tcl >= 8.5

%description    tk
This package includes the Tk-based tkagg backend
for the %{name} plotting package

%package        web
Summary:        Web backend for %{name}
Requires:       %{name} = %{version}
Requires:       python-tornado

%description    web
This package includes the browser-based webagg backend
for the %{name} plotting package

%if 0%{?suse_version} > 1500
%package        wx
Summary:        WxWidgets backend for %{name}
Requires:       %{name} = %{version}
Requires:       python-wxPython >= 4

%description    wx
This package includes the wxWidgets-based wxagg backend
for %{name} plotting package
%endif

%prep
%autosetup -p1 -n matplotlib-%{version}
%{python_expand # Extract freetype and qhull to the right location, so that matplotlib will not try to download it
mkdir build
pushd build
tar xfz %{SOURCE98}
tar xfz %{SOURCE99}
popd
}

chmod -x lib/matplotlib/mpl-data/images/*.svg
find lib/matplotlib lib/mpl_toolkits/mplot3d -type f -name "*.py" -exec sed -i "1{/#!.*python/ d}" {} \;
cp %{SOURCE1} mplsetup.cfg
# The setup procedure wants certifi to download packages over https. Not applicable here.
sed -i '/"certifi>=.*"/ d' pyproject.toml

%build
%if %{without test}
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%{python_expand sed -i -e "s/install matplotlib from source/install the $python-matplotlib-testdata package/" \
                      %{buildroot}%{$python_sitearch}/matplotlib/tests/__init__.py
}
%{?python_compileall}
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%if %{with test}
%check
# force 'swrast' ("llvmpipe") Mesa/OpenGL driver to be used by
# setting and exporting LIBGL_ALWAYS_SOFTWARE=1 to get rid of
# issues when Mesa is trying to load 'zink' driver (messages are
# just warnings, but seem to be fatal for the tests here) (boo#1219095)
export LIBGL_ALWAYS_SOFTWARE=1
# fails to detect alternative backend within xvfb
skip_tests+=" or test_backend_fallback_headful"
# test_usetex.py::test_usetex[png] - no tex text -- do not skip test_empty[png] and test_unicode_minus[png]
skip_tests+=" or (test_usetex and png and not empty and not unicode)"
# output slightly differs: text moves a bit
skip_tests+=" or test_pdflatex"
# timing tests on obs can fail unpredictably
skip_tests+=" or test_invisible_Line_rendering"
# too much memory consumption on obs parallel workers
skip_tests+=" or (test_agg and chunksize) or test_throw_rendering_complexity_exceeded"
# testing interactive backend leaks inside obs is flaky
skip_tests+=" or (test_backends_interactive and test_figure_leak_20490)"
# flaky signal termination tests inside obs
skip_tests+=" or _sigint"
# test finds extra system fonts not found by the mpl fontmanager
skip_tests+=" or test_get_font_names"
# different default font
skip_tests+=" or test_bold_font_output_with_none_fonttype"
# different position values on python311 (different version in a dependency or different font?)
skip_tests+=" or test_compressed1"
%ifnarch x86_64
# image comparison failures due to precisions dicrepancies to the x86 produced references
skip_tests+=" or png or svg or pdf"
%endif
# backend tests landing in the wrong xdist process may fail with an error. Test them without xdist.
no_xdist="test_backend or test_span_selector_animated_artists_callback"
%{python_expand # see https://matplotlib.org/devdocs/devel/testing.html#testing
# if one of the pyargs modules is not present, the xargs collection looks empty
$python -m pytest --pyargs matplotlib.tests \
                           mpl_toolkits.axes_grid1.tests \
                           mpl_toolkits.axisartist.tests \
                           mpl_toolkits.mplot3d.tests \
                  -n auto \
                  -m "not network" \
                  -vv -rsfE \
                  -k "not (${no_xdist} ${skip_tests})"
$python -m pytest --pyargs matplotlib.tests \
                  -vv -rsfE \
                  -k "(${no_xdist}) and not (${skip_tests:4})"
}
%endif

%if %{without test}
%files %{python_files}
%doc README.md
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib
%{python_sitearch}/matplotlib-%{version}.dist-info
%dir %{python_sitearch}/mpl_toolkits
%{python_sitearch}/mpl_toolkits/axes_grid1
%{python_sitearch}/mpl_toolkits/axisartist
%{python_sitearch}/mpl_toolkits/mplot3d
%{python_sitearch}/pylab.py*
%pycache_only %{python_sitearch}/__pycache__/pylab.*
%exclude %{python_sitearch}/matplotlib/backends/_backend_tk.py
%exclude %{python_sitearch}/matplotlib/backends/_backend_gtk.py
%exclude %{python_sitearch}/matplotlib/backends/backend_cairo.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk3.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk3agg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk3cairo.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk4.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk4agg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk4cairo.*
%exclude %{python_sitearch}/matplotlib/backends/backend_nbagg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_qt5.*
%exclude %{python_sitearch}/matplotlib/backends/backend_qt5agg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_qt5cairo.py*
%exclude %{python_sitearch}/matplotlib/backends/backend_tkagg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_tkcairo.*
%exclude %{python_sitearch}/matplotlib/backends/backend_webagg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_webagg_core.*
%exclude %{python_sitearch}/matplotlib/backends/backend_wx.*
%exclude %{python_sitearch}/matplotlib/backends/backend_wxagg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_wxcairo.*
%exclude %{python_sitearch}/matplotlib/backends/qt_compat.*
%exclude %{python_sitearch}/matplotlib/backends/qt_editor/
%exclude %{python_sitearch}/matplotlib/backends/web_backend/
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/_backend_tk.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/_backend_gtk.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_cairo.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3agg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3cairo.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk4.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk4agg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk4cairo.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_nbagg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5agg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5cairo.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_tkagg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_tkcairo.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg_core.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_wx.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_wxagg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_wxcairo.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/qt_compat.*.py*
%exclude %{python_sitearch}/matplotlib/tests/baseline_images
%exclude %{python_sitearch}/mpl_toolkits/axes_grid1/tests/baseline_images
%exclude %{python_sitearch}/mpl_toolkits/axisartist/tests/baseline_images
%exclude %{python_sitearch}/mpl_toolkits/mplot3d/tests/baseline_images
%exclude %{python_sitearch}/matplotlib/tests/tinypages

# Dummy package to pull in latex dependencies.
%files %{python_files latex}
%license LICENSE/
%license doc/users/project/license.rst

%files %{python_files cairo}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/backend_cairo.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_cairo.*.py*

%files %{python_files gtk3}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/backend_gtk3.py*
%{python_sitearch}/matplotlib/backends/backend_gtk3agg.py*
%{python_sitearch}/matplotlib/backends/backend_gtk3cairo.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3agg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3cairo.*.py*

%files %{python_files gtk4}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/backend_gtk4.py*
%{python_sitearch}/matplotlib/backends/backend_gtk4agg.py*
%{python_sitearch}/matplotlib/backends/backend_gtk4cairo.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk4.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk4agg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk4cairo.*.py*

%files %{python_files gtk-common}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/_backend_gtk.py
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/_backend_gtk.*.py*

%if 0%{?suse_version} > 1500 && 0%{?python_version_nodots} >= 310
%files %{python_files nbagg}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/backend_nbagg.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_nbagg.*.py*
%endif

%files %{python_files qt}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/backend_qt5.py*
%{python_sitearch}/matplotlib/backends/backend_qt5agg.py*
%{python_sitearch}/matplotlib/backends/backend_qt5cairo.py*
%{python_sitearch}/matplotlib/backends/qt_compat.py*
%{python_sitearch}/matplotlib/backends/qt_editor/
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5agg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5cairo.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/qt_compat.*.py*

%files %{python_files testdata}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/tests/baseline_images
%{python_sitearch}/mpl_toolkits/axes_grid1/tests/baseline_images
%{python_sitearch}/mpl_toolkits/axisartist/tests/baseline_images
%{python_sitearch}/mpl_toolkits/mplot3d/tests/baseline_images
%{python_sitearch}/matplotlib/tests/tinypages
%exclude %{python_sitearch}/matplotlib/tests/tinypages/.gitignore
%exclude %{python_sitearch}/matplotlib/tests/tinypages/_static/.gitignore

%files %{python_files tk}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/_backend_tk.py*
%{python_sitearch}/matplotlib/backends/backend_tkagg.py*
%{python_sitearch}/matplotlib/backends/backend_tkcairo.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/_backend_tk.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_tkagg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_tkcairo.*.py*

%files %{python_files web}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/backend_webagg.py*
%{python_sitearch}/matplotlib/backends/backend_webagg_core.py*
%{python_sitearch}/matplotlib/backends/web_backend/
%exclude %{python_sitearch}/matplotlib/backends/web_backend/.*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg_core.*.py*

%if 0%{?suse_version} > 1500
%files %{python_files wx}
%license LICENSE/
%license doc/users/project/license.rst
%{python_sitearch}/matplotlib/backends/backend_wx.py*
%{python_sitearch}/matplotlib/backends/backend_wxagg.py*
%{python_sitearch}/matplotlib/backends/backend_wxcairo.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_wx.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_wxagg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_wxcairo.*.py*
%endif
%endif

%changelog
* Thu Apr 18 2024 Ben Greiner <code@bnavigator.de>
- Update to 3.8.4
  * Enable building against numpy 2.0; released wheels are built
    against numpy 2
  * Add a draw during show for macos backend
  * Fix color sequence data for Set2 and Set3
  * gtk: Ensure pending draws are done before GTK draw
  * Update "Created with" url in hand.svg
  * Avoid modifying user input to Axes.bar
  * fix quiver3d incorrect arrow colors
* Sat Mar 23 2024 Dirk Müller <dmueller@suse.com>
- update to 3.8.3:
  * Fix crash at exit for PGF backend
* Fri Mar 22 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Fri Mar 22 2024 Fabian Vogt <fvogt@suse.com>
- Add explicit BuildRequires on Mesa-dri, needed to run tests
* Tue Mar 19 2024 Antonio Larrosa <alarrosa@suse.com>
- Do not BuildRequire PyQt6 in SLE15. We don't want to include
  the whole qt6 stack in SLE only for matplotlib tests.
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Don't build nbagg for python39: ipython not available anymore
* Fri Feb 23 2024 Max Lin <mlin@suse.com>
- Disable nbagg and wx plugin on Leap15/SLE15
  * Leap 15 doesn't have IPython stack with python 3.11 build
  * python-wxPython with python 3.11 supported needs wxWidgets
    version >= 3.2.0 as the minimal requirement which Leap15/SLE15
    don't have that
* Tue Jan 23 2024 Stefan Dirsch <sndirsch@suse.com>
- force 'swrast' ("llvmpipe") Mesa/OpenGL driver to be used by
  setting and exporting LIBGL_ALWAYS_SOFTWARE=1 to get rid of
  issues when Mesa is trying to load 'zink' driver (messages are
  just warnings, but seem to be fatal for the tests here) (boo#1219095)
* Sun Dec 17 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.8.2
  * Bugfix release without API changes
- API Changes for 3.8.1
  [#]# Behaviour
  * Default behaviour of hexbin with C provided requires at least 1
    point
  [#]# Deprecations
  * Deprecations removed in contour
- What's new in 3.8
  [#]# Type Hints
  [#]# Plotting and Annotation improvements
  * Support customizing antialiasing for text and annotation
  * rcParams for AutoMinorLocator divisions
  * Axline setters and getters
  * Clipping for contour plots
  * Axes.ecdf
  * Figure.get_suptitle(), Figure.get_supxlabel(),
    Figure.get_supylabel()
  * Ellipse.get_vertices(), Ellipse.get_co_vertices()
  * Remove inner ticks in label_outer()
  * Configurable legend shadows
  * offset parameter for MultipleLocator
  * Add a new valid color format (matplotlib_color, alpha)
  * The pie chart shadow can be controlled
  * PolyQuadMesh is a new class for drawing quadrilateral meshes
  * Shadow shade can be controlled
  * SpinesProxy now supports calling the set() method
  * Allow setting the tick label fonts with a keyword argument
  [#]# Figure, Axes, and Legend Layout
  * pad_inches="layout" for savefig
  * Add a public method to modify the location of Legend
  * rcParams['legend.loc'] now accepts float-tuple inputs
  [#]# Mathtext improvements
  * Boldsymbol mathtext command \boldsymbol
  * mathtext has more sizable delimiters
  * mathtext documentation improvements
  * mathtext now supports \substack
  * mathtext now supports \middle delimiter
  * mathtext operators
  * mathtext spacing corrections
  * mathtext now supports \text
  * Bold-italic mathtext command \mathbfit
  [#]# 3D plotting improvements
  * Specify ticks and axis label positions for 3D plots
  * 3D hover coordinates
  * 3D plots can share view angles
  [#]# Other improvements
  * matplotlib.mpl_toolkits is now an implicit namespace package
  * Plot Directive now can make responsive images with "srcset"
- API Changes for 3.8.0
  [#]# Behaviour Changes
  * Tk backend respects file format selection when saving figures
  * Placing of maximum and minimum minor ticks
  * hexbin now defaults to rcParams["patch.linewidth"]
  * TwoSlopeNorm now auto-expands to always have two slopes
  * Event objects emitted for axes_leave_event
  * Streamplot now draws streamlines as one piece if no width or no
    color variance
  * canvas argument now required for FigureFrameWx
  * ContourSet is now a single Collection
  * SubFigure default facecolor is now transparent
  * Reject size related keyword arguments to MovieWriter grab_frame
    method
  * Changes of API after deprecation
  * Invalid types for Annotation xycoords now raise TypeError
  * Default antialiasing behavior changes for Text and Annotation
  * ScalarMappable.to_rgba() now respects the mask of RGB(A) arrays
  * Text.get_rotation_mode return value
  * PostScript paper type adds option to use figure size
  * hexbin mincnt parameter made consistently inclusive
  [#]# Deprecations
  * Calling paths.get_path_collection_extents with empty offsets
  * axes_grid1.axes_divider API changes
  * bbox.anchored() with no explicit container
  * Functions in mpl_toolkits.mplot3d.proj3d
  * Arguments other than renderer to get_tightbbox
  * The object returned by pcolor() has changed to a PolyQuadMesh
    class
  * LocationEvent.lastevent
  * allsegs, allkinds, tcolors and tlinewidths attributes of
    ContourSet
  * ContourSet.collections
  * INVALID_NON_AFFINE, INVALID_AFFINE, INVALID attributes of
    TransformNode
  * Grouper.clean()
  * GridHelperCurveLinear.get_data_boundary
  * np_load parameter of cbook.get_sample_data
  * RendererAgg.tostring_rgb and FigureCanvasAgg.tostring_rgb
  * The parameter of Annotation.contains and Legend.contains is
    renamed to mouseevent
  * Accessing event.guiEvent after event handlers return
  * Widgets
  * Method parameters renamed to match base classes
  * numdecs parameter and attribute of LogLocator
  * NavigationToolbar2QT.message is deprecated
  * ft2font.FT2Image.draw_rect and ft2font.FT2Font.get_xys
  * backend_ps.psDefs
  * Callable axisartist Axes
  * AnchoredEllipse is deprecated
  * Automatic papersize selection in PostScript
  * Tick.set_label1 and Tick.set_label2
  * Passing extra positional arguments to Figure.add_axes
  * CbarAxesBase.toggle_label
  * TexManager.texcache
  * Artists explicitly passed in will no longer be filtered by
    legend() based on their label
  * FigureCanvasBase.switch_backends
  * cbook.Stack is deprecated
  * inset_location.InsetPosition is deprecated
  * axisartist.axes_grid and axisartist.axes_rgb
  * ContourSet.antialiased
  * Passing non-int or sequence of non-int to
    Table.auto_set_column_width
  * PdfPages(keep_empty=True)
  * Auto-closing of figures when switching backend
  * Support for passing the "frac" key in annotate(...,
    arrowprops={"frac": ...})
  [#]# Removals
  * cbook removals
  * Groupers from get_shared_x_axes / get_shared_y_axes are
    immutable
  * Deprecated modules removed
  * Parameters to plt.figure() and the Figure constructor
  * stem(..., use_line_collection=False)
  * Positional / keyword arguments
  * Methods to set parameters in LogLocator and LogFormatter*
  * Axes.get_renderer_cache
  * Unused methods in Axis, Tick, XAxis, and YAxis
  * mlab.stride_windows
  * Axes3D
  * 3D Axis
  * checkdep_usetex removed
  * date_ticker_factory removed
  * transforms.Affine2D.identity()
  * Removals in testing.decorators
  * text.get_rotation()
  * Passing too many positional arguments to tripcolor
  * The filled argument to Colorbar is removed
  * Widgets
  * Axes3D.set_frame_on and Axes3D.get_frame_on removed
  * Miscellaneous internals
  * Backend-specific removals
  * Removal of deprecated APIs
- What's new in 3.7
  [#]# Plotting and Annotation improvements
  * hatch parameter for pie
  * Polar plot errors drawn in polar coordinates
  * Additional format string options in bar_label
  * ellipse boxstyle option for annotations
  * The extent of imshow can now be expressed with units
  * Reversed order of legend entriespcolormesh accepts RGB(A)
    colors
  * View current appearance settings for ticks, tick labels, and
    gridlines
  * Style files can be imported from third-party packages
  [#]# Improvements to 3D Plotting
  * 3D plot pan and zoom buttons
  * adjustable keyword argument for setting equal aspect ratios in
    3D
  * Poly3DCollection supports shading
  * rcParam for 3D pane color
  [#]# Figure and Axes Layout
  * colorbar now has a location keyword argument
  * Figure legends can be placed outside figures using
    constrained_layout
  * Per-subplot keyword arguments in subplot_mosaic
  * subplot_mosaic no longer provisional
  [#]# Widget Improvements
  * Custom styling of button widgets
  * Blitting in Button widgets
  [#]# Other Improvements
  * Source links can be shown or hidden for each Sphinx plot
    directive
  * Figure hooks
- API Changes in 3.7
  [#]# Behaviour Changes
  * All Axes have get_subplotspec and get_gridspec methods now,
    which returns None for Axes not positioned via a gridspec
  * HostAxesBase.get_aux_axes now defaults to using the same base
    axes class as the host axes
  * plt.get_cmap and matplotlib.cm.get_cmap return a copy
  * TrapezoidMapTriFinder uses different random number generator
  * FuncAnimation(save_count=None)
  * CenteredNorm halfrange is not modified when vcenter changes
  * fig.subplot_mosaic no longer passes the gridspec_kw args to
    nested gridspecs.
  * HPacker alignment with bottom or top are now correct
  * On Windows only fonts known to the registry will be discovered
  * QuadMesh.set_array now always raises ValueError for inputs with
    incorrect shapes
  * contour and contourf auto-select suitable levels when given
    boolean inputs
  * contour no longer warns if no contour lines are drawn.
  * AxesImage.set_extent now raises TypeError for unknown keyword
    arguments
  * Change of legend(loc="best") behavior
  [#]# Deprecations
  * Axes subclasses should override clear instead of cla
  * rcParams type
  * Deprecation aliases in cbook
  * draw_gouraud_triangle
  * matplotlib.pyplot.get_plot_commands
  * matplotlib.tri submodules are deprecated
  * Passing undefined label_mode to Grid
  * Colorbars for orphaned mappables are deprecated, but no longer
    raise
  * Animation attributes
  * contour.ClabelText and ContourLabeler.set_label_props
  * ContourLabeler attributes
  * backend_ps.PsBackendHelper and backend_ps.ps_backend_helper
  * backend_webagg.ServerThread is deprecated
  * parse_fontconfig_pattern will no longer ignore unknown constant
    names
  * BufferRegion.to_string and BufferRegion.to_string_argb
  * num2julian, julian2num and JULIAN_OFFSET
  * unit_cube, tunit_cube, and tunit_edges
  * Most arguments to widgets have been made keyword-only
  * SimpleEvent
  * RadioButtons.circles
  * CheckButtons.rectangles and CheckButtons.lines
  * OffsetBox.get_extent_offsets and OffsetBox.get_extent
  * legend.legendHandles
  * ticklabels parameter of Axis.set_ticklabels renamed to labels
  * offsetbox.bbox_artist
  * Quiver.quiver_doc and Barbs.barbs_doc
  * Deprecate unused parameter x to TextBox.begin_typing
  * Deprecation of top-level cmap registration and access functions
    in mpl.cm
  * BrokenBarHCollection is deprecated
  * Passing inconsistent loc and nth_coord to axisartist helpers
  * passthru_pt
  * axes3d.vvec, axes3d.eye, axes3d.sx, and axes3d.sy
  * Line2D
  [#]# Removals
  * epoch2num and num2epoch are removed
  * Locator and Formatter wrapper methods
  * Interactive cursor details
  * auto_add_to_figure=True for Axes3D
  * The first parameter of Axes.grid and Axis.grid has been renamed
    to visible
  * Removal of deprecations in the Selector widget API
  * backend_template.show
  * Unused positional parameters to print_<fmt> methods
  * QuadMesh signature
  * Expiration of FancyBboxPatch deprecations
  * Testing support
  * Auto-removal of grids by pcolor and pcolormesh
  * Modification of Axes children sublists
  * Passing incorrect types to Axes.add_* methods
  * ConversionInterface.convert no longer accepts unitless values
  * Normal list of Artist objects now returned by
    HandlerLine2D.create_artists
  * rcParams will no longer cast inputs to str
  * Case-insensitive scales
  * Support for nx1 = None or ny1 = None in AxesLocator and
    Divider.locate
  * change signature of .FigureCanvasBase.enter_notify_event
  * Colorbar tick update parameters
  * plot directive removals
  * Miscellaneous removals
- Drop pyparsing-workaround-setName.patch
- Update the -qt5 backend module name to -qt since it also supports
  PyQt6 and PySide{2,6}
- Add nbagg backend subpackage
- Test some optional stuff outside of Ring1
* Tue Jul 11 2023 Markéta Machová <mmachova@suse.com>
- add pyparsing-workaround-setName.patch as a part of a workaround
  for boo#1213007
  * it changes the behaviour for the debugging purposes, the laic
    end user shouldn't notice
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Wed Feb  8 2023 Arun Persaud <arun@gmx.de>
- update to version 3.6.3:
  * Fix Artist removal from axes_grid1 Axes classes
  * Fix inset_locator in subfigures
  * Fix scatter on masked arrays with units
  * Fix colorbar ticks with log norm contours
  * Fix deprecation warnings in GTK4 backend
  * Fix using relative paths in HTMLWriter
  * Improve failure message from rcParams string validation for tuple
    inputs
  * Improve performance of QtAgg backends
  * No longer modify pil_kwargs argument to imsave and savefig
* Thu Dec 22 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.6.2
  * Avoid mutating dictionaries passed to subplots
  * Fix bbox_inches='tight' on a figure with constrained layout
    enabled
  * Fix auto-scaling of ax.hist density with histtype='step'
  * Fix compatibility with PySide6 6.4
  * Fix evaluating colormaps on non-NumPy arrays
  * Fix key reporting in pick events
  * Fix thread check on PyPy 3.8
  * Handle input to ax.bar that is all NaN
  * Make rubber band more visible on Tk and Wx backends
  * Restore (and warn on) seaborn styles in style.library
  * Restore get_renderer function in deprecated tight_layout
  * nb/webagg: Fix resize handle on WebKit browsers (e.g., Safari)
- Release 3.6.1
  * A warning is no longer raised when constrained layout
    explicitly disabled and tight layout is applied
  * Add missing get_cmap method to ColormapRegistry
  * Adding a colorbar on a ScalarMappable that is not attached to
    an Axes is now deprecated instead of raising a hard error
  * Fix barplot being empty when first element is NaN
  * Fix FigureManager.resize on GTK4
  * Fix fill_between compatibility with NumPy 1.24 development
    version
  * Fix hexbin with empty arrays and log scaling
  * Fix resize_event deprecation warnings when creating figure on
    macOS
  * Fix build in mingw
  * Fix compatibility with PyCharm's interagg backend
  * Fix crash on empty Text in PostScript backend
  * Fix generic font families in SVG exports
  * Fix horizontal colorbars with hatches
  * Fix misplaced mathtext using eqnarray
  * stackplot no longer changes the Axes cycler
- Release 3.6.0
  [#]# Figure and Axes creation / management
  * subplots, subplot_mosaic accept height_ratios and width_ratios
    arguments
  * Constrained layout is no longer considered experimental
  * New layout_engine module
  * Compressed layout added for fixed-aspect ratio Axes
  * Layout engines may now be removed
  * Axes.inset_axes flexibility
  * WebP is now a supported output format
  * Garbage collection is no longer run on figure close
  [#]# Plotting methods
  * Striped lines (experimental)
  * Custom cap widths in box and whisker plots in bxp and boxplot
  * Easier labelling of bars in bar plot
  * New style format string for colorbar ticks
  * Linestyles for negative contours may be set individually
  * Improved quad contour calculations via ContourPy
  * errorbar supports markerfacecoloralt
  * streamplot can disable streamline breaks
  * New axis scale asinh (experimental)
  * stairs(..., fill=True) hides patch edge by setting linewidth
  * Fix the dash offset of the Patch class
  * Rectangle patch rotation point
  [#]# Colors and colormaps
  * Color sequence registry
  * Colormap method for creating a different lookup table size
  * Setting norms with strings
  [#]# Titles, ticks, and labels
  * plt.xticks and plt.yticks support minor keyword argument
  [#]# Legends
  * Legend can control alignment of title and handles
  * ncol keyword argument to legend renamed to ncols
  [#]# Markers
  * marker can now be set to the string "none"
  * Customization of MarkerStyle join and cap style
  [#]# Fonts and Text
  * Font fallback
  * List of available font names
  * math_to_image now has a color keyword argument
  * Active URL area rotates with link text
  [#]# rcParams improvements
  * Allow setting figure label size and weight globally and
    separately from title
  * Mathtext parsing can be disabled globally
  * Double-quoted strings in matplotlibrc
  [#]# 3D Axes improvements
  * Standardized views for primary plane viewing angles
  * Custom focal length for 3D camera
  * 3D plots gained a 3rd "roll" viewing angle
  * Equal aspect ratio for 3D plots
  [#]# Interactive tool improvements
  * Rotation, aspect ratio correction and add/remove state
  * MultiCursor now supports Axes split over multiple figures
  * PolygonSelector bounding boxes
  * Setting PolygonSelector vertices
  * SpanSelector widget can now be snapped to specified values
  * More toolbar icons are styled for dark themes
  [#]# Platform-specific changes
  * Wx backend uses standard toolbar
- Drop upstream patch fix-tests-pytest72.patch
- Move to PEP518 build
* Wed Dec  7 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-tests-pytest72.patch to fix tests failing with pytest 7.2
  gh#matplotlib/matplotlib#24173
* Fri Nov 11 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove also setuptools_scm_git_archive dependency as it's suggested in the
  release post
  https://discourse.matplotlib.org/t/matplotlib-announce-amm-matplotlib-3-5-3/23046
* Fri Nov 11 2022 Daniel Garcia <daniel.garcia@suse.com>
- Allow build with setuptools_scm>=7
* Sun Aug 14 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * removed pathc matplotlib-pr22975-fixarray.patch; included upstream
- update to version 3.5.3:
  * Fix alignment of over/under symbols
  * Fix bugs in colorbars:
    + alpha of extensions
    + drawedges=True with extensions
    + handling of panchor=False
  * Fix builds on Cygwin and IBM i
  * Fix contour labels in SubFigures
  * Fix cursor output:
    + for imshow with all negative values
    + when using BoundaryNorm
  * Fix interactivity in IPython/Jupyter
  * Fix NaN handling in errorbar
  * Fix NumPy conversion from AstroPy unit arrays
  * Fix positional markerfmt passed to stem
  * Fix unpickling:
    + crash loading in a separate process
    + incorrect DPI when HiDPI screens
* Thu May 26 2022 Ben Greiner <code@bnavigator.de>
- Skip a flaky leak test, move sigint test skip to all archs
- Add matplotlib-pr22975-fixarray.patch,
  gh#matplotlib/matplotlib#22975, required for astropy 5.1
* Wed May  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.5.2:
  * Preliminary support for Windows on arm64 target has been added; this
    requires FreeType 2.11 or above.
- drop matplotlib-pr22780-Pillow-deprecations.patch (upstream)
* Tue Apr 12 2022 Ben Greiner <code@bnavigator.de>
- Add matplotlib-pr22780-Pillow-deprecations.patch for
  deprecation errors with Pillow -- gh#matplotlib/matplotlib#22780
- Skip any test with svg png or pdf in its id for non x86_64, as
  image comparison tests compare to x86_64 references.
* Tue Dec 14 2021 Ben Greiner <code@bnavigator.de>
- Skip tests which crash with oom
* Sun Dec 12 2021 Ben Greiner <code@bnavigator.de>
- Update to version 3.5.1
  * https://matplotlib.org/stable/users/prev_whats_new/whats_new_3.5.0.html
  * Figure and Axes creation / management
  - subplot_mosaic supports simple Axes sharing
  - Figure now has draw_without_rendering method
  - Figure __init__ passes keyword arguments through to set
  * Plotting methods
  - Add Annulus patch
  - set_data method for FancyArrow patch
  - New arrow styles in ArrowStyle and ConnectionPatch
  - Setting collection offset transform after initialization
  * Colors and colormaps
  - Colormap registry (experimental)
  - Image interpolation now possible at RGBA stage
  - imshow supports half-float arrays
  - A callback registry has been added to Normalize objects
  * Titles, ticks, and labels
  - Settings tick positions and labels simultaneously in
    set_ticks
  * Fonts and Text
  - Triple and quadruple dot mathtext accents
  - Font properties of legend title are configurable
  - Text and TextBox added parse_math option
  - Text can be positioned inside TextBox widget
  - Simplifying the font setting for usetex mode
  - Type 42 subsetting is now enabled for PDF/PS backends
  * rcParams improvements
  - Allow setting default legend labelcolor globally
  * 3D Axes improvements
  - Axes3D now allows manual control of draw order
  - Allow changing the vertical axis in 3d plots
  - plot_surface supports masked arrays and NaNs
  - 3D plotting methods support data keyword argument
  * Interactive tool improvements
  - Colorbars now have pan and zoom functionality
  - Updated the appearance of Slider widgets
  - Removing points on a PolygonSelector
  - Dragging selectors
  - Clearing selectors
  - Setting artist properties of selectors
  - Ignore events outside selection
  - CallbackRegistry objects gain a method to temporarily block
    signals
  - Directional sizing cursors
  * Sphinx extensions
  - More configuration of mathmpl sphinx extension
  * Backend-specific improvements
  - GTK backend
  - Qt backends
  - HiDPI support in Cairo-based, GTK, and Tk backends
  - Qt figure options editor improvements
  - WX backends support mouse navigation buttons
  - WebAgg uses asyncio instead of Tornado
- Add gtk4 and gtk-common subpackages
* Wed Dec  8 2021 Steve Kowalik <steven.kowalik@suse.com>
- Skip some broken tests with new pyparsing.
* Sat Oct 23 2021 Axel Braun <axel.braun@gmx.de>
- version 3.4.3
  Patches removed (in version 3.4.3):
  inkscape11.patch
  0001-FIX-Pillow-asarray-bug.patch
  0002-Dont-modify-arrays-when-masking-values-for-log.patch
* Tue Jul 27 2021 Markéta Machová <mmachova@suse.com>
- Fix tests with inkscape11.patch
* Wed Jul  7 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patches from upstream to fix an raised exception saying
  "__array__(): takes 1 positional argument but 2 were given"
  and an incompatibility with numpy 1.21.0 (slightly rebased):
  * 0001-FIX-Pillow-asarray-bug.patch
  * 0002-Dont-modify-arrays-when-masking-values-for-log.patch
* Fri May 14 2021 Arun Persaud <arun@gmx.de>
- update to version 3.4.2:
  * Generate wheels usable on older PyPy7.3.{0,1}
  * Fix compatibility with Python 3.10
  * Add subplot_mosaic Axes in the order the user gave them to us
  * Correctly handle 'none' facecolors in do_3d_projection
  * Ensure that Matplotlib is importable even if there's no HOME
  * Fix CenteredNorm with halfrange
  * Fix bar_label for bars with NaN values
  * Fix clip paths when zoomed such that they are outside the figure
  * Fix creation of RangeSlider with valinit
  * Fix handling of "d" glyph in backend_ps, fixing EPS output
  * Fix handling of datetime coordinates in pcolormesh with Pandas
  * Fix processing of some errorbar arguments
  * Fix removal of shared polar Axes
  * Fix resetting grid visibility
  * Fix subfigure indexing error and tight bbox
  * Fix textbox cursor color
  * Fix TkAgg event loop error on window close
  * Ignore errors for sip with no setapi (Qt4Agg import errors)
* Fri May  7 2021 Ben Greiner <code@bnavigator.de>
- Update build and runtime TeX requirements for -latex subpackage.
* Thu Apr 29 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add a required BuildRequires on tex(geometry.sty).
* Sun Apr  4 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update numpy requirement
  * removed patch no-builddir-freetype.patch and instead put the source files directly into a
    directory that works with the current build system
  * also added qhull source code (which otherwise the build process tries to download)
- update to version 3.4.1:
  * fix errorbar when specifying fillstyle
  * fix Inkscape cleanup at exit on Windows for tests
  * fix legends of colour-mapped scatter plots
  * fix positioning of annotation fancy arrows
  * fix size and color rendering for 3D scatter plots
  * fix suptitle manual positioning when using constrained layout
  * respect antialiasing settings in cairo backends as well
- changes from version 3.4.0:
  * Figure and Axes creation / management
    + New subfigure functionality
    + Single-line string notation for subplot_mosaic
    + Changes to behavior of Axes creation methods (gca, add_axes,
    add_subplot)
    + add_subplot/add_axes gained an axes_class parameter
    + Subplot and subplot2grid can now work with constrained layout
  * Plotting methods
    + axline supports transform parameter
    + New automatic labeling for bar charts
    + A list of hatches can be specified to bar and barh
    + Setting BarContainer orientation
    + Contour plots now default to using ScalarFormatter
    + Axes.errorbar cycles non-color properties correctly
    + errorbar errorevery parameter matches markevery
    + hexbin supports data reference for C parameter
    + Support callable for formatting of Sankey labels
    + Axes.spines access shortcuts
    + New stairs method and StepPatch artist
    + Added orientation parameter for stem plots
    + Angles on Bracket arrow styles
    + TickedStroke patheffect
  * Colors and colormaps
    + Collection color specification and mapping
    + Transparency (alpha) can be set as an array in collections
    + pcolormesh has improved transparency handling by enabling
    snapping
    + IPython representations for Colormap objects
    + Colormap.set_extremes and Colormap.with_extremes
    + Get under/over/bad colors of Colormap objects
    + New cm.unregister_cmap function
    + New CenteredNorm for symmetrical data around a center
    + New FuncNorm for arbitrary normalizations
    + GridSpec-based colorbars can now be positioned above or to the
    left of the main axes
  * Titles, ticks, and labels
    + supxlabel and supylabel
    + Shared-axes subplots tick label visibility is now correct for
    top or left labels
    + An iterable object with labels can be passed to Axes.plot
  * Fonts and Text
    + Text transform can rotate text direction
    + matplotlib.mathtext now supports overset and underset LaTeX
    symbols
    + math_fontfamily parameter to change Text font family
    + TextArea/AnchoredText support horizontalalignment
    + PDF supports URLs on Text artists
  * rcParams improvements
    + New rcParams for dates: set converter and whether to use
    interval_multiples
    + Date formatters now respect usetex rcParam
    + Setting image.cmap to a Colormap
    + Tick and tick label colors can be set independently using
    rcParams
  * 3D Axes improvements
    + Errorbar method in 3D Axes
    + Stem plots in 3D Axes
    + 3D Collection properties are now modifiable
    + Panning in 3D Axes
  * Interactive tool improvements
    + New RangeSlider widget
    + Sliders can now snap to arbitrary values
    + Pausing and Resuming Animations
  * Sphinx extensions
    + plot_directive caption option
  * Backend-specific improvements
    + Consecutive rasterized draws now merged
    + Support raw/rgba frame format in FFMpegFileWriter
    + nbAgg/WebAgg support middle-click and double-click
    + nbAgg support binary communication
    + Indexed color for PNG images in PDF files when possible
    + Improved font subsettings in PDF/PS
    + Kerning added to strings in PDFs
    + Fully-fractional HiDPI in QtAgg
    + wxAgg supports fullscreen toggle
* Sat Feb 13 2021 Benjamin Greiner <code@bnavigator.de>
- Skip python36 build. Due to NEP 29 there is no python36-numpy in
  Tumbleweed anymore.
* Sat Jan 30 2021 Arun Persaud <arun@gmx.de>
- update to version 3.3.4:
  * Fix WebAgg initialization.
  * Fix parsing QT_API setting with mixed case.
  * Fix build with link-time optimization disabled in environment.
  * Fix test compatibility with NumPy 1.20.
  * Fix test compatibility with pytest 6.2.
* Thu Jan 14 2021 Benjamin Greiner <code@bnavigator.de>
- Update to v3.3.3
  This release contains several critical bug-fixes:
  * Fix calls to Axis.grid with argument visible=True.
  * Fix fully masked imshow.
  * Fix inconsistent color mapping in scatter for 3D plots.
  * Fix notebook/nbAgg figures when used with ipywidgets in the
    same cell.
  * Fix notebook/nbAgg/WebAgg on older (e.g., Firefox ESR)
    browsers.
  * Fix pcolormesh with datetime coordinates.
  * Fix performance regression with datetimes.
  * Fix singular ticks with small log ranges.
  * Fix timers/animations on wx and notebook backends.
  * Remove certifi as a hard runtime dependency.
- Changelog for v3.3.2
  This release contains several critical bug-fixes:
  * fix Axis scale on twinned Axes
  * fix auto-close of Figures in nbagg
  * fix automatic title placement if Axes is off the Figure
  * fix autoranging of log scales with barstacked histogram
  * fix extra redraws when using Button or TextBox widgets
  * fix imshow with LogNorm and large vmin/vmax ranges
  * fix plotting Pandas DataFrame with string MultiIndex
  * fix scatter with marker=''
  * fix scatter3d color/linewidth re-projection
  * fix state of mode buttons in TkAgg backends
  * include license files in built distribution
  * reduce Visual C++ runtime requirements on Windows
- Changelog for v3.3.1
  This release contains several critical bug-fixes:
  * fix docstring import issues when running Python with optimization
  * fix hist with categorical data, such as with Pandas
  * fix install on BSD systems
  * fix nbagg compatibility with Chrome 84+
  * fix ordering of scatter marker size in 3D plots
  * fix performance regression when plotting Paths
  * fix reading from URL in imread
  * fix several regressions with new date epoch handling
  * fix some bad constrained and tight layout interactions with colorbars
  * fix use of customized toolbars in TkAgg and WXAgg backends
- remove transparent_markers.pdf
- fix rich rpm recommends
- fix broken compilation of cache files
* Thu Jan 14 2021 Benjamin Greiner <code@bnavigator.de>
- Run backend tests without xdist. They fail when they end up
  in the wrong process.
* Thu Oct 22 2020 Ismail Dönmez <idonmez@suse.com>
- Copy updated transparent_markers.pdf from upstream commit
  https://github.com/matplotlib/matplotlib/pull/18604 to fix
  test failure Ghostscript 9.53
* Thu Jul 23 2020 Benjamin Greiner <code@bnavigator.de>
- Require Pillow
- Bump dependency versions
* Mon Jul 20 2020 Benjamin Greiner <code@bnavigator.de>
- Work on unit testing
  * Move architecture selection to bcond definition at top of
    specfile. This makes it clear in the OBS web UI that the test
    flavor is only built for x86_64 and aarch64
  * do not build everything a second time during check (in-place)
  * instead use new subpackage testdata wich contains the baseline
    images created at regular build time
  * use pytest-xvfb and %%pytest macro
    (buildroot path actually not required)
  * tidy test skip definitions
  * add python-gobject-Gdk to pass the gtk3 backend testso
- include version for obsoletes -qt-shared (rpmlint warning)
- move some cairo files to backend packages
- remove python2 transition requirements mock and six
- update matplotlib-setup.cfg
* Sat Jul 18 2020 Todd R <toddrme2178@gmail.com>
- update to version 3.3.0
  + Figure and Axes creation / management
  * Provisional API for composing semantic axes layouts from text or nested lists
  * GridSpec.subplots()
  * New Axes.sharex, Axes.sharey methods
  * tight_layout now supports suptitle
  * Setting axes box aspect
  + Colors and colormaps
  * Turbo colormap
  * colors.BoundaryNorm supports extend keyword argument
  * Text color for legend labels
  * Pcolor and Pcolormesh now accept shading='nearest' and 'auto'
  + Titles, ticks, and labels
  * Align labels to Axes edges
  * Allow tick formatters to be set with str or function inputs
  * Axes.set_title gains a y keyword argument to control auto positioning
  * Offset text is now set to the top when using axis.tick_top()
  * Set zorder of contour labels
  + Other changes
  * New Axes.axline method
  * imshow now coerces 3D arrays with depth 1 to 2D
  * Better control of Axes.pie normalization
  * Dates use a modern epoch
  * Lines now accept MarkerStyle instances as input
  + Fonts
  * Simple syntax to select fonts by absolute path
  * Improved font weight detection
  + rcParams improvements
  * matplotlib.rc_context can be used as a decorator
  * rcParams for controlling default "raise window" behavior
  * Add generalized mathtext.fallback to rcParams
  * Add contour.linewidth to rcParams
  + 3D Axes improvements
  * Axes3D no longer distorts the 3D plot to match the 2D aspect ratio
  * 3D axes now support minor ticks
  * Home/Forward/Backward buttons now work with 3D axes
  + Interactive tool improvements
  * More consistent toolbar behavior across backends
  * Toolbar icons are now styled for dark themes
  * Cursor text now uses a number of significant digits matching pointing precision
  * GTK / Qt zoom rectangle now black and white
  * Event handler simplifications
  + Functions to compute a Path's size
  * Better interface for Path segment iteration
  * Fixed bug that computed a Path's Bbox incorrectly
  + Backend-specific improvements
  * savefig() gained a backend keyword argument
  * The SVG backend can now render hatches with transparency
  * SVG supports URLs on more artists
  * Images in SVG will no longer be blurred in some viewers
  * Saving SVG now supports adding metadata
  * Saving PDF metadata via PGF now consistent with PDF backend
  * NbAgg and WebAgg no longer use jQuery & jQuery UI
- Rebase no-builddir-freetype.patch
* Wed Jun 24 2020 Todd R <toddrme2178@gmail.com>
- update to version 3.2.2:
  * Unit converters recognize subclasses
  * imsave accepts metadata and PIL options
  * cbook.normalize_kwargs
  * FontProperties accepts os.PathLike
  * Gouraud-shading alpha channel in PDF backend
  * Kerning adjustments now use correct values
  * bar3d lightsource shading
  * Shifting errorbars
  * Improvements in Logit scale ticker and formatter
  * rcParams for axes title location and color
  * 3-digit and 4-digit hex colors
* Thu Jun  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip tests that randomly fail
- Run the tests on 64bit arm and intel only as elsewhere there are
  >100 test failures
* Mon May 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch no-builddir-freetype.patch to not require freetype
  in build/ subfolder which we use in python macros
  * This is SUSE specific patch
- Make the package multibuild and execute the testsuite
* Mon May 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove the is_opensuse literals as we don't want to have matplotlib
  behave differently between openSUSE and SLE jsc#SLE-11752
* Fri May 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove the qt4 code support as we do just Qt5 everywhere
* Sat Mar 28 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * tkagg.py and wx_compat.py are not part of the build process anymore
    (the backends still exist though); removed appropiate files from %%files section
- update to version 3.2.1:
  * fix Quiver.set_UVC calls with scalar inputs
  * fix bezier.get_parallels failure from floating point rounding
    errors
  * fix markers specified as tuples (polygons, stars, or asterisks)
  * fix saving PNGs to file objects in some places
  * fix saving figures using the nbAgg/notebook backend
  * fix saving with tight layout using the PGF backend
  * fix setting custom datapath in rcParams (note: it is still
    deprecated)
  * fix various issues running setup.py in non-CI environments
  * fix xpdf distiller
  * various minor bug and documentation fixes
- changes from version 3.2.0:
  * default image interpolation is now `'antialiased'` to better
    handle down-sampling and reduce artifacts when up-sampling by
    small ratios.
  * change when ticks switch to using an offset to improve readability
  * improvements to auto-scaling and auto-limits
  * `DivergingNorm` has been renamed to `TwoSlopeNorm`
  * support for 3 and 4 digit hex colors (`#123` maps to `#112233`)
  * improvements to Logit scale ticker and formatter
  * control of where errorbars start getting placed with `errorevery`
  * correct kerning when laying out text
  * improvements to MovieRegistry
  * For the full details please see the whats new [1] and API changes
    [2] in the documentation
    [1] https://matplotlib.org/3.2.0/users/whats_new.html
    [2] https://matplotlib.org/3.2.0/api/api_changes.html
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 3.1.3
  * suppress a warning with Pandas 1.0
  * support pillow >= 7
  * support dateutils >= 2.8.1
  * prevent an infinite recursion
  * do not clobber non-python registered signal handler
  * fix path intersection computation with 0 length segments
  * fix performance regression in draw_idle
  * several minor bugs
* Fri Dec  6 2019 Todd R <toddrme2178@gmail.com>
- Update to 3.1.2
  * fix regresion of incorrect limits for y-axis in imshow
  * fix integer indexed pandas series
  * fix ScalarFormatter formatting of masked values
  * webagg and nbagg no longer incorrectly fallback to agg when $DISPLAY is not set
  * several fixes for Qt5 backend
  * other bugfixes and documentation fixes
* Mon Oct 14 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Disable Qt4 on Leap 15.2+
* Sat Jul  6 2019 Arun Persaud <arun@gmx.de>
- update to version 3.1.1:
  * The first bug-fix release of the 3.1 series
    + Locator.nonsingular return order API change
  * Lots of backports of various bug fixes.
* Sun May 19 2019 Todd R <toddrme2178@gmail.com>
- update to version 3.1.0:
  + New Features
  * `~.dates.ConciseDateFormatter`
  * Secondary x/y Axis support
  * `~.scale.FuncScale` for arbitrary axes scales
  * Legend for scatter
  * Matplotlib no longer requires framework app build on MacOSX backend
  + Figure, FigureCanvas, and Backends
  * Figure.frameon is now a direct proxy for the Figure patch visibility state
  * *pil_kwargs* argument added to savefig
  * Add ``inaxes`` method to `.FigureCanvasBase`
  * cairo backend defaults to pycairo instead of cairocffi
  + Axes and Artists
  * axes_grid1 and axisartist Axes no longer draw spines twice
  * Return type of ArtistInspector.get_aliases changed
  * `.ConnectionPatch` accepts arbitrary transforms
  * mplot3d Line3D now allows {set,get}_data_3d
  * ``Axes3D.voxels`` now shades the resulting voxels
  + Axis and Ticks
  * Added `.Axis.get_inverted` and `.Axis.set_inverted`
  * Adjust default minor tick spacing
  * `.EngFormatter` now accepts `usetex`, `useMathText` as keyword only arguments
  + Animation and Interactivity
  * Support for forward/backward mouse buttons
  * *progress_callback* argument to `~.Animation.save()`
  * Add ``cache_frame_data`` keyword-only argument into `.animation.FuncAnimation`
  * Endless Looping GIFs with PillowWriter
  * Adjusted `.matplotlib.widgets.Slider` to have vertical orientation
  * Improved formatting of image values under cursor when a colorbar is present
  * MouseEvent button attribute is now an IntEnum
  + Configuration, Install, and Development
  * The MATPLOTLIBRC environment variable can now point to any "file" path
  * Allow LaTeX code ``pgf.preamble`` and ``text.latex.preamble`` in MATPLOTLIBRC file
  * New logging API
- Switch to upstream-recommended python-cairo instead of
  python-cairocffi
* Fri Mar  1 2019 Arun Persaud <arun@gmx.de>
- update to version 3.0.3:
  * fix several possible memory leaks
  * documentation fixes
  * jquery-ui is no longer bundled in git repo and is downloaded
    during the install or sdist process. If you are installing from
    pypi the files will be included, but if you are installing from
    git you will need internet access the first time you run `pip
    install .`. The install process tries to cache the files and will
    not need internet access on future installations.
* Wed Feb 27 2019 Fabian Vogt <fvogt@suse.com>
- Disable Qt4 support on Tumbleweed by default
* Mon Nov 12 2018 Arun Persaud <arun@gmx.de>
- update to version 3.0.2:
  * Un-breaks basemap which was broken by partially restoring private
    APIs for cartopy.
  * Fixes bug in warning code when used in an embedded context.
  * Fixes crash when using Tk and closing the first open window before
    showing it
  * Many documentation improvements.
  * Restore a corner case on ColorBar tick usage.
  * Change the default behavior of `matplotlib.use` to silently allow
    more 'safe' switching after auto-discovery, but before starting an
    event loop.
  * Improvements to bounding box calculations.
  * Provide the correct length for RcParams instances.
* Fri Oct 26 2018 Todd R <toddrme2178@gmail.com>
- Update to version 3.0.1
  * Fix failure to import bug when on Python 3.6.7 and 3.7.1
  * Fixed a number of failure to import bugs around finding fonts
  * Fix Qt4 backend
  * Fix bug on OSX that recursively searched current directory for fonts
  * Fix bouncing-rocket on OSX when doing backend fallback and not
    selecting OSX
  * Temporarily restore several private APIs to unbreak cartopy
  * Make pyplot more tolerant of varying signatures in 3rd-party
    sub-classe
  * Improve datetime64 unit handling
  * Fixed several poor interactions with tight_layout
* Wed Sep 19 2018 Todd R <toddrme2178@gmail.com>
- Update to version 3.0.0
  * Improved default backend selection
  * Cyclic colormaps
  * Ability to scale axis by a fixed order of magnitude
  * Add AnchoredDirectionArrows feature to mpl_toolkits
  * Add minorticks_on()/off() methods for colorbar
  * Colorbar ticks can now be automatic
  * Don't automatically rename duplicate file names
  * Legend now has a *title_fontsize* kwarg (and rcParam)
  * Support for axes.prop_cycle property *markevery* in rcParams
  * Multipage PDF support for pgf backend
  * Pie charts are now circular by default
  * Add ax.get_gridspec to .SubplotBase
  * Axes titles will no longer overlap xaxis
  * New convenience methods for GridSpec
  * Figure has an ~.figure.Figure.add_artist method
  * math directive renamed to mathmpl
- Python 2 support was dropped upstream, so disable it in the spec
  file and drop python2-specific parts (bsc#1184340, bsc#1198319)
- Enable wx backend for python 3, since python 3 is now supported
  by wxPython upstream.
* Tue Aug 14 2018 toddrme2178@gmail.com
- Update to version 2.2.3
  * Fix import failure on BSD systems
  * Fix import errors in Qt shims for PyQt5 5.11 and PyQt4 4.12
  * Fix import errors if bz2 module is not in standard library
  * Fix overflow in _path.h
  * Fix infinite recursion in transform repr
  * Fix bug with XKCD style
  * Remove unsafe usage of Popen
* Sat Jun  2 2018 hpj@urpla.net
- don't use any lua expressions for suse_version < 1500
* Fri Jun  1 2018 dimstar@opensuse.org
- Only recommend python-matplotlib-tk if tk is already flagged for
  installation. On most systems there is no reason to have tk
  available (those UIs are out of date and not well perceived
  anyway).
* Tue May 15 2018 tbechtold@suse.com
- Add missing Requires for python-backports.functools_lru_cache (boo#1074491)
* Thu May 10 2018 toddrme2178@gmail.com
- Fix building on SLE which doesn't have qhull.
* Sat Mar 17 2018 arun@gmx.de
- update to version 2.2.2:
  * v2.2.1 did not actually restore matplotlib.verbose.
- changes from version 2.2.1:
  * This release fixes a number of critical bugs:
    + restores matplotlib.verbose (fixing embedding in pycharm)
    + preserve precision when color mapping small portions of data
    with extreme outliers
    + fixes saving long movies with ffmpeg
    + fixes UnbourdLocal error in contour labeling
    + fixes import failure on python 3.4.0 and 3.4.1
    + fixes compile time failures with clang on 32bit platforms
    + fixes an icon in the Tk backends
    + fixes several issues with Tables
    + fixes expanding offset boxes with tight_layout
    + revert changes to the font caching to avoid a possible bug in
    backports.lru_cache
    + numerous docstring and documentation fixes
  * We have reverted the deprecation of `font_manager.TempCache`.
* Thu Mar  8 2018 arun@gmx.de
- specfile:
  * require kiwisolver
  * update required version for dateutil
- update to version 2.2.0:
  * The first release of the v2.2 LTS series and the last version of
    Matplotlib to support python2.  There will be bug-fix release for
    this series until 2020.
  * This release includes new features including:
    + An experimental constrained layout manager
    + Color blind friendly color map (cividis) and color cycle
    (tableau-colorblind10)
    + native support for numpy.datetime64 types
    + animated gif writing via pillow
    + TkAgg now works with pypy
    + cairo based backends for Qt, Tk, and WX
  * There are several API changes in this release:
    + To support the constrained layout Matplotlib has a new required
    dependency (kiwisolver).
    + The `matplotlib.finance` module has been removed, development
    has moved to a stand-alone project.
* Tue Jan 30 2018 rolf@rotkraut.de
- Update versions of required packages.
* Sun Jan 28 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.1.2:
  * This release fixes a number of critical bugs:
    + fix a typo in mlab.cohere which yielded incorrect results
    + allow nonposx / nonposy to pass through loglog
    + fix color comparisons when finding handles with legend
    + fixes a recursive draw bug and a major performance regression in
    Qt5Agg backend
    + fix a re-draw bug in WxAgg
    + fix image scaling with high-bit depth integers
    + revert the busy-cursor
* Wed Jan 17 2018 thod_@gmx.de
- dependency changed to python-six >= 1.10
  (see "site-packages/matplotlib/__init__.py", line 187)
* Sat Dec 16 2017 arun@gmx.de
- update to version 2.1.1:
  * The first and only planned bug-fix release for the 2.1 series.
  * This release include many bug and documentation fixes.  Highlights
    are:
    + change default logscale behavior to clip
    + fixed webagg import errors
    + tweaks to polar ticks
    + fixed exception when guessing afm family names
    + update manifest to include all doc files
    + improve masked array handling in pcolormesh
    + fix segfault from reading invalid png
    + fix blocking_input
    + fix bug resulting in huge multi-page pdf files
    + make `show` in nbagg take args as other backends do
    + several fixes to OSX backend
    + restore positional arg handling on Figure.legend
    + fix bugs in interactive navigation
    + fix issues when panning with invalid limits
    + fix bug with fully masked arrays passed to imshow
* Thu Oct 26 2017 toddrme2178@gmail.com
- Update to version 2.1.0
  + New features
  * String categorical values
  * Interactive JS widgets for animation
  * Enhancements to polar plot
  * Figure class now has subplots method
  * Metadata savefig keyword argument
  * Busy Cursor
  * PolygonSelector
  * Added matplotlib.ticker.PercentFormatter
  * Reproducible PS, PDF and SVG output
  * Orthographic projection for mplot3d
  * voxels function for mplot3d
  + Improvements
  * Add capstyle and joinstyle attributes to Collection
  * CheckButtons widget get_status function
  * Add fill_bar argument to AnchoredSizeBar
  * Annotation can use a default arrow style
  * Barbs and Quiver Support Dates
  * Hexbin default line color
  * Figure.legend() can be called without arguments
  * Multiple legend keys for legend entries
  * New parameter clear for :func:`~matplotlib.pyplot.figure`
  * Specify minimum value to format as scalar for LogFormatterMathtext
  * New quiverkey angle keyword argument
  * Colormap reversed method
  * Artist.setp (and pyplot.setp) accept a file argument
  * streamplot streamline generation more configurable
  * Axis.set_tick_params now responds to rotation
  * Shading in 3D bar plots
  * New which Parameter for autofmt_xdate
  * New Figure Parameter for subplot2grid
  * Interpolation in fill_betweenx
  * New keyword argument sep for EngFormatter
  * Extend MATPLOTLIBRC behavior
  * density kwarg to hist
  + Internals
  * New TransformedPatchPath caching object
  * Abstract base class for movie writers
  * Stricter validation of line style rcParams
  + Performance
  * Path simplification updates
  * Implement intersects_bbox in c++\
- Remove upstream-included patches:
  * 0001-Fix-include-path-for-system-libqhull.patch
  * 0001-Allow-divmod-to-be-overridden-by-num.patch
  * 166a14473272_Fix-contour-colour-level-determination.patch
  * 97e170d2fc2c_Pass-integers-to-np_linspace.patch
* Mon Oct  9 2017 stefan.bruens@rwth-aachen.de
- Fix/enhance build with tests:
  - set PYTHONPATH, otherwise tests will not find the python
    modules installed to the buildroot
  - Add BuildRequires for several tex styles/resources
  - Add BuildRequires: xorg-x11-Xvfb, needed for Qt backend tests
  - Remove python-Pillow, tests are only using png, not e.g jpeg
  - increase image compare tolerance, our Freetype 2.7 renders
    slightly different to the baseline FT 2.6
  - Add upstream 0001-Allow-divmod-to-be-overridden-by-num.patch,
    to cope with numpy 1.13 changes
  - Add upstream 166a14473272_Fix-contour-colour-level-determination.patch
  - Add upstream 97e170d2fc2c_Pass-integers-to-np_linspace.patch
* Mon Oct  9 2017 stefan.bruens@rwth-aachen.de
- Also remove runtime-only python-tk dependecy from BuildRequires:
* Sat Oct  7 2017 stefan.bruens@rwth-aachen.de
- Rebase the matplotlib setup.cfg on upstream version
- Guard several BuildRequires: which are not necessary for building
  with the "tests" conditional, most backends are pure python
- Do not install/package baseline images only necessary for tests,
  shrinks the main package by 60 MByte
* Thu Aug 10 2017 toddrme2178@gmail.com
- Update to version 2.0.2
  Critical bug fixes for 2.0.1
  * fixed Qt4 support
  * fixed LogFormatter
  * fixed hatched artists in legends
  * fixed segfault with large images
- Update to version 2.0.1
  Bug fix release for 2.0.x series
  This release includes bug fixes, documentation updates and one major change.
  + API
  * Do not clip the linewidth used for dash pattern scaling.  This is
    an API change, but is a major improvement.
  * Deprecate 'vega' color names in favor of 'tab'.
  + Bug Fixes
  * Hatching color follows edge color again.
  * Fixes a critical bug with masked images.
  * Improved high-dpi support for Qt5.
  * Log ticking no never skip minor ticks
  * Do not skip points surrounded by nan/inf in vector outputs.
- Disable backends on releases that don't support them.
* Thu Jul 13 2017 stefan.bruens@rwth-aachen.de
- Add 0001-Fix-include-path-for-system-libqhull.patch
  Avoid falling back to outdated bundled version
* Sun Apr 30 2017 toddrme2178@gmail.com
- Restore qt4 backend since qt4 still has maintained,
  python3-comptible python bindings.
- Provide/obsolete gtk backend to avoid conflicts.
  It doesn't have maintained, python3-compatible python bindings.
* Mon Mar 27 2017 toddrme2178@gmail.com
- Implement single-spec version
- Drop old qt4 and gtk2 backends
- Drop unmaintained qt designer widget
* Fri Mar 10 2017 toddrme2178@gmail.com
- Fix file list
* Fri Jan 20 2017 toddrme2178@gmail.com
- Add python-functools32 dependency.
* Tue Jan 17 2017 toddrme2178@gmail.com
- update to version 2.0.0
  + Highlights include:
  * 'viridis' is default color map instead of jet.
  * Modernized the default color cycle.
  * Many more functions respect the color cycle.
  * Line dash patterns scale with linewidth.
  * Change default font to DejaVu, now supports most Western alphabets (including Greek, Cyrillic and Latin with diacritics), math symbols and emoji out of the box.
  * Faster text rendering.
  * Improved auto-limits.
  * Ticks out and only on the right and bottom spines by default.
  * Improved auto-ticking, particularly for log scales and dates.
  * Improved image support (imshow respects scales and eliminated a class of artifacts).
* Fri Dec  2 2016 sbahling@suse.com
- update to version 1.5.3
  * Changed default autorange behavior in boxplots (introduced with
    1.5.2)
- Change BuildRequires and Recommends from python-Pillow to
  python-imaging to allow for SLE 12 builds. (python-Pillow
  provides python-imaging)
* Sat Jul 30 2016 jengelh@inai.de
- Make use of wxWidgets 3
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Mon Jan 11 2016 toddrme2178@gmail.com
- Update to version 1.5.1:
  First bug fix release for 1.5.x series.
* Wed Dec  2 2015 egeorget@openmailbox.org
- Enabled qt5 on Leap 42.1
- Enabled wx on Leap 42.1
* Wed Nov 25 2015 p.drouand@gmail.com
- Drop agg-devel dependenxy; useless
* Fri Oct 30 2015 toddrme2178@gmail.com
- Add new python-Cycler dependency
* Fri Oct 30 2015 toddrme2178@gmail.com
- Update to 1.5.0
  * Auto-redraw using the object-oriented API.
  * Most plotting functions now support labeled data API.
  * Color cycling has extended to all style properties.
  * Four new perceptually uniform color maps, including the
    soon-to-be default 'viridis'.
  * More included style sheets.
  * Many small plotting improvements.
  * Proposed new framework for managing the GUI toolbar and tools.
* Wed Jul  1 2015 toddrme2178@gmail.com
- Disable qt5 on SLE 12
- Disable wx on SLE 11 and 12
- Disable latex and gtk3 on SLE 11
- Don't require texlive-sfmath on SLE 12
- Disable qt5 on ppc and arm
- Depend on libxml2 instead of libxml2-tools
* Thu May 21 2015 toddrme2178@gmail.com
- Fix installed files
* Mon Mar  2 2015 toddrme2178@gmail.com
- specfile:
  * update url
  * update source url to point to pypi
- update to version 1.4.3:
  * Many bugs are fixed including:
  - fixing drawing of edge-only markers in AGG
  - fix run-away memory usage when using %%inline or saving with a
    tight bounding box with QuadMesh artists
  - improvements to wx and tk gui backends
  * Additionally the webagg and nbagg backends were brought closer to
    feature parity with the desktop backends with the addition of
    keyboard and scroll events thanks to Steven Silvester.
* Mon Oct 27 2014 toddrme2178@gmail.com
- Update to 1.4.2.  This is a bug-fix release for the 1.4 series.
  - corrected boxplot in pyplot.py
  - added extra paths to default search paths for freetype
* Mon Oct 20 2014 toddrme2178@gmail.com
- Update to 1.4.1.  This is a bug-fix release for the 1.4 series.
  - reverts the changes to interactive plotting so ion will work as
    before in all cases fixed boxplot regressions
  - fixes for finding freetype and libpng
  - sundry unicode fixes (looking up user folders, importing
    seaborn/pandas/networkx with macosx backend)
  - nbagg works with python 3 + new font awesome
  - fixed saving dialogue in QT5
* Thu Sep 18 2014 toddrme2178@gmail.com
- Create subpackage to pull in latex dependencies so they are more
  visible to users.
- Comment out testing BuildRequires since we aren't doing testing.
  We aren't doing testing because it takes a long time and a lot
  of packages depend on matplotlib, so it slows down the build
  process for python packages too much.
* Wed Sep 17 2014 jmatejek@suse.com
- downgrade Recommends for texlive (and other big packages) to Suggests
  (this means texlive is not pulled in by default zypper settings)
* Wed Sep 10 2014 toddrme2178@gmail.com
- Dependency and spec file cleanups
- Remove unneeded use-setuptools.diff
* Thu Aug 28 2014 dmueller@suse.com
- adjust python-tz buildrequires to match runtime requires (python-pytz)
* Wed Aug 27 2014 toddrme2178@gmail.com
- Add new python-cairocffi dependency.  This is the recommended
  dependency for the cairo backend upstream.
- Split out the cairo backend into its own subpackage.  It is no
  longer tied to gtk, so people can use it on its own without
  pulling in any gtk dependencies.
- Fixed issues with qt.  The qt5 backend is actually a generic
  qt backend, which the qt4 backend depends on.  So it needs to be
  available for the qt4 backend to work at all.  However, we need
  to pull in the python-qt5 package to make it work, and that
  package is only available for openSUSE > 13.1.  So we need to
  split the generic qt stuff, including the qt5 stuff, into a
  package both the qt4 and qt5 backends can depend on, and then
  create a stub qt5 package that just pulls in python-qt5
- Reorganized some other backend packages based on backend changes
* Tue Aug 26 2014 toddrme2178@gmail.com
- Update to 1.4.0
  * New colormap for red-green color blind users
  * Documentation changes
  - Phil Elson rewrote of the documentation and userguide for both
    Legend and PathEffects.
  * New plotting features
  - Power-law normalization
  - Fully customizable boxplots
  - Support for datetime axes in 2d plots
  - Support for additional spectrum types
  - Support for detrending and windowing 2D arrays in mlab
  - Support for strides in mlab
  - Formatter for new-style formatting strings
  - Consistent grid sizes in streamplots
  - Get a list of all tick labels (major and minor)
  - Separate horizontal/vertical axes padding support in ImageGrid
  - Support for skewed transformations
  - Support for specifying properties of wedge and text in pie
    charts.
  - Fixed the direction of errorbar upper/lower limits
  - More consistent add-object API for Axes
  - Violin Plots
  - More `markevery` options to show only a subset of markers
  - Added size related functions to specialized `Collections`
  - Fixed the mouse coordinates giving the wrong theta value in
    Polar graph
  - Simple quiver plot for mplot3d toolkit
  - polar-plot r-tick locations
  * Date handling
  - n-d array support for date conversion
  * Configuration (rcParams)
  - 'savefig.transparent' added
  - 'axes.titleweight'
  - 'axes.formatter.useoffset' added
  * XDG compliance
  - Matplotlib now looks for configuration files (both rcparams and
    style) in XDG compliant locations.
  * 'style' package added
  - You can now easily switch between different styles using the
    new 'style' package
  * Backends
  - Qt5 backend added
  - Qt4 backend
    + Rudolf Höfler changed the appearance of the subplottool.
    + In the figure options dialog one can now choose to
    (re-)generate a simple automatic legend.
    + Interactive performance of the Qt4 backend has been
    dramatically improved under windows.
    + The mapping of key-signals from Qt to values matplotlib
    understands was greatly improved (For both Qt4 and Qt5).
  - Cairo backends
    +  The Cairo backends are now able to use the cairocffi
    bindings, which are more actively maintained than the pycairo
    bindings.
  - Gtk3Agg backend
    +  The Gtk3Agg backend now works on Python 3.x, if the cairocffi
    bindings are installed.
  - PDF backend
    +  Added context manager for saving to multi-page PDFs.
  * Text
  - Text URLs supported by SVG backend
  - Anchored sizebar font
  * Sphinx extensions
  - The context directive in the plot_directive Sphinx extension
    can now accept an optional reset setting, which will cause the
    context  to be reset.
  * Widgets
  - Span Selector
  * Added an option span_stays to SpanSelector which makes the
    selector rectangle stay on the axes after you release the
    mouse.
  * GAE integration
  - Matplotlib will now run on google app engine.
- Added python-qt5 backend on openSUSE > 13.1
- Spec file cleanups
* Wed Jul 16 2014 toddrme2178@gmail.com
- Set dummy XDG_RUNTIME_DIR to fix building on openSUSE:Factory
* Thu Apr 10 2014 dmueller@suse.com
- install LICENSE directory and fix license tag
* Wed Apr  9 2014 dmueller@suse.com
- add use-setuptools.diff: build against old setuptools as well
* Fri Mar 28 2014 speilicke@suse.com
- Package doc/users/license.rst
* Mon Mar 17 2014 i@marguerite.su
- fix bnc#863451
- added windowing.* to python-matplotlib-tk
- It's windowing instead of Windows, a module required by tk backend
* Sat Mar  8 2014 bwiedemann@suse.com
- Recommend python-matplotlib-tk because it is the default config
* Thu Jan  9 2014 dmueller@suse.com
- remove qt4/designer subpackages for SLE11, as those can
  not be installed without additional updates on a SLES+SDK system
* Thu Nov 14 2013 toddrme2178@gmail.com
- Enable all backends
- Split most backends into separate packages
- Update dependencies
- Add many optional dependencies
- Make %%setup.py quiet
* Thu Oct 24 2013 speilicke@suse.com
- Update to version 1.3.1:
  + Many changes
* Thu Aug 29 2013 jmatejek@suse.com
- add Requires: python-pyparsing
  (the pyparsing module is required for mathtext rendering)
* Wed Aug 21 2013 highwaystar.ru@gmail.com
- update to 1.3.0
- New features:
  * xkcd-style sketch plotting
  * New eventplot plot type
  * Triangular grid interpolation
  * Baselines for stackplot
  * Rectangular colorbar extensions
  * Calling subplot() without arguments
- Drawing:
  * Independent alpha values for face and edge colors
  * Path effects on lines
  * Easier creation of colormap and normalizer for levels with colors
  * Full control of the background color
  * Improved bbox_inches="tight" functionality
  * Initialize a rotated rectangle
- Text:
  * Anchored text support
  * Better vertical text alignment and multi-line text
  * Left and right side axes titles
  * Improved manual contour plot label positioning
- Configuration (rcParams)
  * Quickly find rcParams
  * Changes to font rcParams
- Backends
  * WebAgg backend
  * Remember save directory
- Documentation and examples:
  * Numpydoc docstrings
  * Example reorganization
  * Examples now use subplots()
- Infrastructure
  * Housecleaning
  * New setup script
  * XDG base directory support
  * Catch opening too many figures using pyplot
- for API changes see
  http://matplotlib.org/api/api_changes.html#changes-in-1-3
- removed patches needed for python3 package
* Mon Nov 12 2012 highwaystar.ru@gmail.com
- update to 1.2.0
  * Python 3.x support
  * PGF/TikZ backend
  * Locator interface
  * Tri-Surface Plots
  * Control the lengths of colorbar extensions
  * Figures are picklable
  * Set default bounding box in matplotlibrc
  * New Boxplot Functionality
  * New RC parameter functionality
  * Streamplot
  * New hist functionality
  * Updated shipped dependencies
  * Face-centred colors in tripcolor plots
  * Hatching patterns in filled contour plots, with legends
- python3 package added
* Tue Aug 21 2012 highwaystar.ru@gmail.com
- bugfix upstream release 1.1.1
* Thu Apr 26 2012 toddrme2178@gmail.com
- Remove configobj buildrequires, all configobj files should have
  been removed from matplotlib years ago
* Tue Mar 20 2012 toddrme2178@gmail.com
- Fix Qt Designer plugin directories
* Fri Mar 16 2012 toddrme2178@gmail.com
- Cleaned up spec file formatting
- Removed tests for obsolete openSUSE versions
- Added Qt Designer plugin from Python(x,y) project
* Tue Jan 10 2012 kukuk@suse.de
- Fix spec file for SLE11 (Group entries did go lost)
* Wed Dec 14 2011 highwaystar.ru@gmail.com
- update to 1.1.0
  * module for drawing sankey diagrams;
  * environment for creating animated graphics – module animation;
  * automated positioning charts, labels, and axes on the canvas – a
  team tight_layout () will distribute them so that they are not
  people came to each other;
  * Work on integration with PySide, although functional is still
    in the beta-version and it is recommended to continue using
    PyQt4;
  * improved mapping and positioning of the legend;
  * simplified work with three-dimensional graphs (module mplot3d),
  also significantly expanded and updated documentation on mplot3d;
  * uniform markers;
  * completely removed the old module support Numerix, now all
  users must use Numpy;
  * fixes some bugs.
- removed patches that now upstream
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Oct 11 2011 jmatejek@suse.com
- fix build failing because Tkinter has a faulty __version__
* Mon Aug 15 2011 ro@suse.de
- fix build for platform == linux3
* Mon Jan 24 2011 toddrme2178@gmail.com
- new version 1.0.1
  This is a bugfix release:
  + Fixed error with Hammer projection.
  + Fixed the placement and angle of axis labels in 3D plots.
  + New rc parameters examples.download and examples.directory
    allow bypassing the download mechanism in get_sample_data.
  + Change Axis.set_view_interval() so that when updating an
    existing interval, it respects the orientation of that
    interval, and can enlarge but not reduce the interval.
  + Handle NaN's correctly in path analysis routines.
  + Fix bug in patch alpha handling, and in bar color kwarg
  + Return Qt4's default cursor when leaving the canvas
- cleanup specfile
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Sat Dec 11 2010 coolo@novell.com
- remove buildrequire on libstdc++
* Sat Jul 17 2010 werner.ho@gmx.de
- new version 1.0.0
* Sat Oct 10 2009 werner.ho@gmx.de
- new version 0.99.1.1
- config file added (seen at home:ocefpaf project)
* Fri Dec 19 2008 lars@linux-schulserver.de
- Update to 0.98.5.2
  + Fix bug where a line with NULL data limits prevents
    subsequent data limits from calculating correctly
  + Major documentation generator changes
  + Fixed dpi-dependent behavior of Legend and fancybox in Text
  + Fix \$ in non-math text with usetex off
  + Fix anti-aliasing when auto-snapping
  + Fix grid lines not moving correctly during pan and zoom
  + Fixed warning in hist() with numpy 1.2
  + Removed the prints in the set_*style commands.  Return the
    list of pprinted strings instead
- 10.2 is gone: remove specific fixes for this distribution
* Mon Nov 24 2008 werner.ho@gmx.de
- replaced scipy by numpy as build requirement
* Wed Aug 20 2008 werner.ho@gmx.de
- removed python-scipy from the requirements list
- added python-dateutil to the requirements list
- added python-pytz to the requirements list
* Sat Aug  9 2008 werner.ho@gmx.de
- new major version 0.98.3
* Tue Aug  5 2008 werner.ho@gmx.de
- new version 0.91.4
* Tue Jul 15 2008 Andrea Florio <andrea@opensuse.org>
- fixed spec file adding missing buildrequires
- made rpmlint happyer
* Fri Jun  6 2008 Werner Hoch <werner.ho@gmx.de>
- new version 0.91.3
* Thu Jan 31 2008 Werner Hoch <werner.ho@gmx.de>
- new version 0.91.2
* Thu Dec  6 2007 Werner Hoch <werner.ho@gmx.de>
- added configobj as an extra requirement
- thus matplotlib will not provide configobj
* Sat Dec  1 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.91.1
- removed build patches, as the build system has been changed
* Fri Sep  7 2007 Werner Hoch <werner.ho@gmx.de>
- fixed build issus of openSUSE 10.3
* Sat Jun  2 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.90.1
- added enable_BUILD_WXAGG.patch
* Wed Mar 21 2007 Werner Hoch <werner.ho@gmx.de>
- removed X-server patches, use Xvfb instead
- created extra wx and tk packages
* Mon Mar 19 2007 Werner Hoch <werner.ho@gmx.de>
- default backend is GTKAgg now
- TkAgg backend works now. Patched the X-Server dependancy away when building
* Sat Mar 10 2007 Werner Hoch <werner.ho@gmx.de>
- improved the BuildRequires list. Tkinter backend has still problems
* Wed Feb 28 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.90.0
* Mon Oct 30 2006 Werner Hoch <werner.ho@gmx.de>
- new version 0.87.7
* Wed Sep 27 2006 Werner Hoch <werner.ho@gmx.de>
- Initial build.
